import 'package:http/http.dart';
import 'package:rec_api_dart/rec_api_dart.dart';

class LoginService extends ServiceBase {
  LoginService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
        );

  Future login(LoginData data, {String platform = 'rec-admin'}) async {
    final body = {
      ...data.toJson(),
      'grant_type': GrantTypes.password,
      'client_id': env.CLIENT_ID,
      'client_secret': env.CLIENT_SECRET,
      'platform': platform,
    };

    return this.post(ApiPaths.token.asUri(env.API_URL), body).then(saveToken);
  }

  Future refreshToken(String? refreshToken) async {
    var body = {
      'grant_type': GrantTypes.refreshToken,
      'client_id': env.CLIENT_ID,
      'client_secret': env.CLIENT_SECRET,
      'refresh_token': refreshToken,
    };

    return this.post(ApiPaths.refreshToken.asUri(env.API_URL), body).then(saveToken);
  }

  static Future saveToken(value) async {
    // TODO: Get rid of Auth here, or rewrite it so that it can be used in dart
    // Currently LoginService can't be used in dart because Auth depends on SecureStorage
    // A better approach would be to pass it in the constructor or let the code that calls login handle this
    await Auth.saveTokenData(value);

    return value;
  }


  Future checkVersion(String? platform, int? version) async {
    var queryParams = {
      'platform': platform,
      'version': version.toString(),
    };

    var uri = ApiPaths.checkVersion.withQueryParams(queryParams).asUri(env.API_URL);

    try {
        var response = await this.get(uri);
        return response;
    } catch (error) {
        return error;
    }
  }
}
